@@ -23,13 +23,28 @@ int prompt_user(const char *string) {
   return strncmp(inbuf, "y", 1) == 0;
 }
 
+int check_perms(const char *path) {
+  int fd;
+
+  if ( ((fd = open(path, O_WRONLY)) == -1) && (errno == EACCES) ) {
+    if ( chmod(path, S_IRUSR | S_IWUSR) == -1 ) {
+      errorp("Unable to reset %s to writable (probably not owner) "
+	     "... skipping", path);
+      return 0;
+    }
+  }
+
+  close(fd);
+  return 1;
+}
+
 int prompt_file(const char *path) {
   int fd, return_value = 1;
   size_t bufsize = strlen(path) + 80;
   char *buf;
 
   if (options & OPT_F)
-    return 1;
+    return check_perms(path);
 
   if ( (buf = (char *)malloc(bufsize)) == NULL ) {
     errorp("Out of memory at line %d in prompt_file()", __LINE__);
@@ -38,8 +53,9 @@ int prompt_file(const char *path) {
 
   if ( ((fd = open(path, O_WRONLY)) == -1) && (errno == EACCES) ) {
     snprintf(buf, bufsize, "Remove write protected file %s? ", path);
-    return_value = prompt_user(buf);
-    close(fd);
+    if ( (return_value = prompt_user(buf)) == 1 ) 
+      return_value = check_perms(path);
+    close(fd); /* close if open succeded, or silently fail */
   } else {
     if (options & OPT_I) {
       snprintf(buf, bufsize, "Remove %s? ", path);
